@@ -5,18 +5,19 @@ import json
 import re as regex
 from abc import ABC as abstract
 from urllib.request import urlopen
+from typing import Callable
 
 class Theme:
     """A theme used to syntax highlight a `CodeBlock`."""
     
-    colors: dict[str, list[str | function]]
+    colors: dict[str, list[str | Callable]]
     """
     The colors of this theme represented as a dictionary. The keys of the dictionary are hexidecimal colors (such as `"#FFFFFF"`), and the values are lists of token types that should be colored with that color (such as `["keyword", "operation"]`).
     """
 
     group_matchers: list[str]
 
-    def __init__(self, colors: dict[str, list[str | function]], group_matchers: list[str]):
+    def __init__(self, colors: dict[str, list[str | Callable]], group_matchers: list[str]):
         """
         Creates a new `Theme` with the specified `colors`. See the `colors` field for specification.
         """
@@ -139,14 +140,16 @@ class CodeBlock(VGroup):
                     elif token.type.startswith('right'):
                         group_count -= 1
                         finished.append('<span foreground="' + theme.group_matchers[group_count % len(theme.group_matchers)] + '">' + token.value + '</span>')
-                    elif token.type == "whitespace": finished.append(token.value)
-                    else: finished.append('<span foreground="' + theme.color_for(token = token) + '">' + token.value + '</span>')
+                    elif token.type == "whitespace": 
+                        finished.append(token.value)
+                    else: 
+                        safe_value = regex.sub("&", "&amp;", token.value)
+                        safe_value = regex.sub("<", "&lt;", safe_value)
+                        safe_value = regex.sub(">", "&gt;", safe_value)
+                        finished.append('<span foreground="' + theme.color_for(token = token) + '">' + safe_value + '</span>')
                 finished.append("\r")
 
             finished_text = "".join(finished)
-            finished_text = regex.sub("&", "&amp;", finished_text)
-            finished_text = regex.sub("><<", ">&lt;<", finished_text)
-            finished_text = regex.sub(">><", ">&gt;<", finished_text)
         else:
             finished_text = '<span foreground="#FFFFFF">' + text + "</span>"
 
